"""Tests for zc.ssl

$Id: tests.py 81831 2007-11-14 13:19:41Z alga $
"""
import unittest
import zope.testing.doctest


class StubSSLWrapper(object):

    def __init__(self, sock, ca_certs=None, cert_reqs=None):
        self.sock = sock
        self.ca_certs = ca_certs
        self.cert_reqs = cert_reqs
        print "sssl(%r, %r, %r)" % (sock, ca_certs, cert_reqs)

    def settimeout(self, timeout):
        print "sssl.settimeout(%r)" % timeout

    def connect(self, hostport):
        print "sssl.connect(%r)" % (hostport, )


def test_suite():
    suite = unittest.TestSuite([
        zope.testing.doctest.DocFileSuite(
        'tests.txt',
        optionflags=zope.testing.doctest.ELLIPSIS),
        ])

    return suite



"""An HTTPS connection implementation that does not:

    * depend on swig
    * ignore server certificates

$Id: __init__.py 110605 2010-04-07 18:36:54Z zvezdan $
"""
import socket
import httplib
import ssl
import os.path
import sys


class HTTPSConnection(httplib.HTTPSConnection):
    """An HTTPS connection using the ssl module"""

    def __init__(self, host, port=None, key_file=None, cert_file=None,
                 strict=None, timeout=None):
        if sys.version_info < (2, 6, 0):
            # timeout is None or float
            self.timeout = timeout
            httplib.HTTPSConnection.__init__(
                self, host, port, key_file, cert_file, strict)
        else:
            httplib.HTTPSConnection.__init__(
                self, host, port, key_file, cert_file, strict, timeout)

        if self.cert_file is None:
            self.cert_file = os.path.join(os.path.dirname(__file__),
                                          "certs.pem")

    ssl_wrap_socket = staticmethod(ssl.wrap_socket)

    def connect(self):
        "Connect to a host on a given (SSL) port."
        sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        self.sock = self.ssl_wrap_socket(sock,
                                         ca_certs=self.cert_file,
                                         cert_reqs=ssl.CERT_REQUIRED)
        self.sock.settimeout(self.timeout)
        self.sock.connect((self.host, self.port))



import sys
from setuptools import setup, find_packages

install_requires = [
    'setuptools',
    'zope.testing',
    ]

if sys.version_info < (2, 6, 0):
    install_requires.append('ssl-for-setuptools')

setup(
    name = "zc.ssl",
    version = "1.2",
    author = "Zope Corporation",
    author_email = "zope-dev@zope.org",
    description = "An HTTPSConnection implementation with the new ssl module",
    keywords = "ssl https",
    packages = find_packages('src'),
    include_package_data = True,
    zip_safe = False,
    package_dir = {'':'src'},
    namespace_packages = ['zc'],
    install_requires = install_requires,
    dependency_links = ['http://download.zope.org/distribution/'],
    license = "ZPL 2.1",
    )
